@@ -45,9 +45,10 @@ tidy.hypotheses <- tidy.comparisons
 glance.slopes <- function(x, ...) {
     insight::check_if_installed("insight")
     insight::check_if_installed("modelsummary")
-    model <- tryCatch(attr(x, "model"), error = function(e) NULL)
+    mfx <- attr(x, "marginaleffects")
+    model <- tryCatch(mfx@model, error = function(e) NULL)
     if (is.null(model) || isTRUE(checkmate::check_string(model))) {
-        model <- tryCatch(attr(x, "call")[["model"]], error = function(e) NULL)
+        model <- tryCatch(mfx@call[["model"]], error = function(e) NULL)
     }
     gl <- suppressMessages(suppressWarnings(try(
         modelsummary::get_gof(model, ...),
@@ -58,11 +59,11 @@ glance.slopes <- function(x, ...) {
     } else {
         out <- NULL
     }
-    vcov.type <- attr(x, "vcov.type")
-    if (is.null(out) && !is.null(vcov.type)) {
-        out <- data.frame("vcov.type" = vcov.type)
+    vcov_type <- components(x, "vcov_type")
+    if (is.null(out) && !is.null(vcov_type)) {
+        out <- data.frame("vcov.type" = vcov_type)
     } else if (!is.null(out)) {
-        out[["vcov.type"]] <- vcov.type
+        out[["vcov.type"]] <- vcov_type
     }
     out <- tibble::as_tibble(out)
     return(out)
