@@ -41,7 +41,7 @@ get_predict.gamlss <- function(
     # predict.gamlss() breaks when `newdata` includes unknown variables
     origindata <- insight::get_data(model)
     originvars <- colnames(origindata)
-    data.table::setDF(newdata)
+    newdata <- as.data.frame(newdata)
     index <- which(colnames(newdata) %in% originvars)
     tmp <- newdata[, index]
     hush(
@@ -54,12 +54,8 @@ get_predict.gamlss <- function(
         )
     )
 
-    if ("rowid" %in% colnames(newdata)) {
-        out <- data.frame(rowid = newdata$rowid, estimate = out)
-    } else {
-        out <- data.frame(rowid = seq_along(out), estimate = out)
-    }
-
+    out <- data.table(estimate = out)
+    out <- add_rowid(out, newdata)
     return(out)
 }
 
@@ -133,7 +129,7 @@ predict_gamlss <- function(
             data <- unlist(tmp)
         }
         namelist <- factor(rep(names, len), levels = names)
-        return(data.frame(data, source = namelist))
+        return(data.table(data, source = namelist))
     }
     if (is.null(newdata)) {
         predictor <- gamlss::lpred(
@@ -357,3 +353,17 @@ predict_gamlss <- function(
     }
     pred
 }
+
+
+#' @include sanity_model.R
+#' @rdname sanitize_model_specific
+#' @export
+sanitize_model_specific.gamlss <- function(model, calling_function, ...) {
+    if (calling_function == "hypotheses") {
+        msg <- "`marginaleffects` does not support hypothesis tests for models of this class."
+        stop_sprintf(msg)
+    }
+    return(model)
+}
+
+
