@@ -13,14 +13,21 @@ get_group_names.mblogit <- function(model, type, ...) {
 #' @include sanity_model.R
 #' @rdname sanitize_model_specific
 #' @export
-sanitize_model_specific.mblogit <- function(model, calling_function = "marginaleffects", ...) {
+sanitize_model_specific.mblogit <- function(
+    model,
+    calling_function = "marginaleffects",
+    ...
+) {
     if (calling_function == "marginaleffects") {
-        variables <- insight::find_variables(model, flatten = TRUE)
+        variables <- insight::find_variables(model, flatten = TRUE, verbose = FALSE)
         dat <- insight::get_data(model)
         dat <- dat[, intersect(variables, colnames(dat))]
         flag <- any(sapply(dat, is.character))
         if (isTRUE(flag)) {
-            stop("Cannot compute marginal effects for models of class `mblogit` when the data includes character variables. Please convert character variables to factors in the dataset before fitting the model, and call `marginaleffects` again.", call. = FALSE)
+            stop(
+                "Cannot compute marginal effects for models of class `mblogit` when the data includes character variables. Please convert character variables to factors in the dataset before fitting the model, and call `marginaleffects` again.",
+                call. = FALSE
+            )
         }
     }
     return(model)
@@ -29,15 +36,20 @@ sanitize_model_specific.mblogit <- function(model, calling_function = "marginale
 
 #' @rdname get_predict
 #' @export
-get_predict.mblogit <- function(model,
-                                newdata = insight::get_data(model),
-                                type = "response",
-                                ...) {
+get_predict.mblogit <- function(
+    model,
+    newdata = insight::get_data(model),
+    type = "response",
+    ...
+) {
     out <- suppressMessages(
-        get_predict.multinom(model = model,
-                             newdata = newdata,
-                             type = type,
-                             ...))
+        get_predict.multinom(
+            model = model,
+            newdata = newdata,
+            type = type,
+            ...
+        )
+    )
     return(out)
 }
 
@@ -47,6 +59,6 @@ get_predict.mblogit <- function(model,
 get_coef.mblogit <- function(model, ...) {
     # get_coef.default uses `insight::get_parameters`, but does not combine
     # Response and Parameter columns. This also matches naming scheme from
-    # `vcov` 
+    # `vcov`
     stats::coef(model)
-}
\ No newline at end of file
+}
