@@ -1,8 +1,7 @@
 supported_engine <- function(x) {
     insight::check_if_installed("parsnip")
     tmp <- parsnip::extract_fit_engine(x)
-    flag <- inherits(try(sanitize_model(tmp), silent = TRUE), "try-error")
-    return(!flag)
+    return(TRUE)
 }
 
 
@@ -40,23 +39,21 @@ get_predict.model_fit <- function(model, newdata, type = NULL, ...) {
 
     if (type == "numeric") {
         v <- intersect(c(".pred", ".pred_res"), colnames(out))[1]
-        out <- data.frame(rowid = seq_len(nrow(out)), estimate = out[[v]])
+        out <- data.table(estimate = out[[v]])
     } else if (type == "class") {
-        out <- data.frame(
-            rowid = seq_len(nrow(out)),
-            estimate = out[[".pred_class"]]
-        )
+        out <- data.table(estimate = out[[".pred_class"]])
     } else if (type == "prob") {
         colnames(out) <- substr(colnames(out), 7, nchar(colnames(out)))
-        out$rowid <- seq_len(nrow(out))
-        data.table::setDT(out)
+        out$marginaleffects_internal_id <- seq_len(nrow(out))
         out <- data.table::melt(
-            out,
-            id.vars = "rowid",
+            as.data.table(out),
+            id.vars = "marginaleffects_internal_id",
             variable.name = "group",
             value.name = "estimate"
         )
+        out$marginaleffects_internal_id <- NULL
     }
+    out <- add_rowid(out, newdata)
 
     return(out)
 }
@@ -73,7 +70,11 @@ get_predict.workflow <- get_predict.model_fit
 #' @rdname get_vcov
 #' @keywords internal
 #' @export
-get_vcov.model_fit <- function(model, type = NULL, ...) {
+get_vcov.model_fit <- function(model, vcov, type = NULL, ...) {
+    if (isFALSE(vcov)) {
+        return(FALSE)
+    }
+
     if (isTRUE(type == "class")) {
         return(FALSE)
     }
