@@ -7,8 +7,7 @@ expect_slopes <- function(
     n_unique = NULL,
     pct_na = 5,
     se = TRUE,
-    ...
-) {
+    ...) {
     insight::check_if_installed("tinytest")
 
     object <- hush(slopes(object, ...))
@@ -16,20 +15,12 @@ expect_slopes <- function(
     diff <- ""
 
     # class
-    fail_class <- !isTRUE(checkmate::check_class(object, "slopes"))
+    fail_class <- !inherits(object, "slopes") || !inherits(object, "marginaleffects")
     if (fail_class) {
         msg <- sprintf("Wrong class: `%s`.", class(object)[1])
         diff <- c(diff, msg)
     }
 
-    # tidy()
-    tid <- hush(tidy(object))
-    fail_tidy <- !isTRUE(checkmate::check_data_frame(tid))
-    if (fail_tidy) {
-        msg <- "tidy() failed to return a data frame."
-        diff <- c(diff, msg)
-    }
-
     # na
     fail_na <- isTRUE(hush(mean(is.na(object$estimate)) * 100 > pct_na))
     if (fail_na) {
@@ -57,7 +48,7 @@ expect_slopes <- function(
     diff <- paste(diff, collapse = "\n")
 
     # pass/fail
-    fail <- fail_class || fail_tidy || fail_na || fail_unique || fail_se
+    fail <- fail_class || fail_na || fail_unique || fail_se
 
     # tinytest object
     out <- tinytest::tinytest(
@@ -74,8 +65,9 @@ expect_slopes <- function(
 #'
 #' @export
 #' @keywords internal
-expect_predictions <- function(object, se = TRUE, n_row = NULL, n_col = NULL) {
+expect_predictions <- function(object, se = TRUE, n_row = NULL, n_col = NULL, ...) {
     insight::check_if_installed("tinytest")
+    object <- hush(predictions(object, ...))
 
     diff <- ""
 
@@ -138,8 +130,7 @@ expect_margins <- function(
     margins_object,
     se = TRUE,
     tolerance = 1e-5,
-    verbose = FALSE
-) {
+    verbose = FALSE) {
     insight::check_if_installed("tinytest")
 
     is_equal <- function(x, y) {
@@ -204,3 +195,123 @@ expect_margins <- function(
 
     return(out)
 }
+
+
+#' `tinytest` helper
+#'
+#' @export
+#' @keywords internal
+expect_hypotheses <- function(object, se = TRUE, n_row = NULL, n_col = NULL, ...) {
+    insight::check_if_installed("tinytest")
+    object <- hush(hypotheses(object, ...))
+
+    diff <- ""
+
+    # class
+    fail_class <- !isTRUE(checkmate::check_class(object, "hypotheses"))
+    if (fail_class) {
+        msg <- sprintf("Wrong class: `%s`.", class(object)[1])
+        diff <- c(diff, msg)
+    }
+
+    # std.error
+    if (isTRUE(se) && !"std.error" %in% colnames(object)) {
+        msg <- "No standard error."
+        diff <- c(diff, msg)
+        fail_se <- TRUE
+    } else {
+        fail_se <- FALSE
+    }
+
+    # rows and cols
+    if (isTRUE(n_row > nrow(object))) {
+        msg <- sprintf("Number of rows: %s", nrow(object))
+        diff <- c(diff, msg)
+        fail_row <- TRUE
+    } else {
+        fail_row <- FALSE
+    }
+
+    if (isTRUE(n_col > ncol(object))) {
+        msg <- sprintf("Number of columns: %s", ncol(object))
+        diff <- c(diff, msg)
+        fail_col <- TRUE
+    } else {
+        fail_col <- FALSE
+    }
+
+    # diff message
+    diff <- paste(diff, collapse = "\n")
+
+    # pass/fail
+    fail <- fail_class || fail_se || fail_row || fail_col
+
+    # tinytest object
+    out <- tinytest::tinytest(
+        result = !fail,
+        call = sys.call(sys.parent(1)),
+        diff = diff
+    )
+
+    return(out)
+}
+
+
+#' `tinytest` helper
+#'
+#' @export
+#' @keywords internal
+expect_comparisons <- function(object, se = TRUE, n_row = NULL, n_col = NULL, ...) {
+    insight::check_if_installed("tinytest")
+    object <- hush(comparisons(object, ...))
+
+    diff <- ""
+
+    # class
+    fail_class <- !isTRUE(checkmate::check_class(object, "comparisons"))
+    if (fail_class) {
+        msg <- sprintf("Wrong class: `%s`.", class(object)[1])
+        diff <- c(diff, msg)
+    }
+
+    # std.error
+    if (isTRUE(se) && !"std.error" %in% colnames(object)) {
+        msg <- "No standard error."
+        diff <- c(diff, msg)
+        fail_se <- TRUE
+    } else {
+        fail_se <- FALSE
+    }
+
+    # rows and cols
+    if (isTRUE(n_row > nrow(object))) {
+        msg <- sprintf("Number of rows: %s", nrow(object))
+        diff <- c(diff, msg)
+        fail_row <- TRUE
+    } else {
+        fail_row <- FALSE
+    }
+
+    if (isTRUE(n_col > ncol(object))) {
+        msg <- sprintf("Number of columns: %s", ncol(object))
+        diff <- c(diff, msg)
+        fail_col <- TRUE
+    } else {
+        fail_col <- FALSE
+    }
+
+    # diff message
+    diff <- paste(diff, collapse = "\n")
+
+    # pass/fail
+    fail <- fail_class || fail_se || fail_row || fail_col
+
+    # tinytest object
+    out <- tinytest::tinytest(
+        result = !fail,
+        call = sys.call(sys.parent(1)),
+        diff = diff
+    )
+
+    return(out)
+}
